@@ -52,7 +52,7 @@ def _parse_error(hstore_str, pos):
 
 
 def _parse_hstore(hstore_str):
-    """Parse an hstore from it's literal string representation.
+    """Parse an hstore from its literal string representation.
 
     Attempts to approximate PG's hstore input parsing rules as closely as
     possible. Although currently this is not strictly necessary, since the
@@ -180,6 +180,7 @@ class HSTORE(sqltypes.Concatenable, sqltypes.TypeEngine):
     """
 
     __visit_name__ = 'HSTORE'
+    hashable = False
 
     class comparator_factory(sqltypes.Concatenable.Comparator):
         """Define comparison operations for :class:`.HSTORE`."""
