@@ -20,7 +20,18 @@ NULLTYPE = None
 STRINGTYPE = None
 
 class TypeEngine(Visitable):
-    """Base for built-in types."""
+    """The ultimate base class for all SQL datatypes.
+
+    Common subclasses of :class:`.TypeEngine` include
+    :class:`.String`, :class:`.Integer`, and :class:`.Boolean`.
+
+    For an overview of the SQLAlchemy typing system, see :ref:`types_toplevel`.
+
+    .. seealso::
+
+        :ref:`types_toplevel`
+
+    """
 
     _sqla_type = True
     _isnull = False
@@ -1039,7 +1050,7 @@ def adapt_type(typeobj, colspecs):
         except KeyError:
             pass
     else:
-        # couldnt adapt - so just return the type itself
+        # couldn't adapt - so just return the type itself
         # (it may be a user-defined type)
         return typeobj
     # if we adapted the given generic type to a database-specific type,
